(v1.3.7)=
### 1.3.7 {small}`2019-01-02`

- API changed from `import scanpy as sc` to `import scanpy.api as sc`.
- {func}`~scanpy.external.tl.phenograph` wraps the graph clustering package Phenograph {cite:p}`Levine2015` {smaller}`thanks to A Mousa`
